DecryptionSharePrecomputed

Struct DecryptionSharePrecomputed 

pub struct DecryptionSharePrecomputed<E: Pairing> {
    pub decrypter_index: usize,
    pub decryption_share: E::TargetField,
    pub validator_checksum: ValidatorShareChecksum<E>,
}
A decryption share for a precomputed variant of the threshold decryption scheme. In this variant, the decryption share is precomputed and can be combined without additional computation on the client side. The downside is that the threshold of decryption shares required to decrypt is equal to the number of private key shares in the scheme.

Fields

decrypter_index: usizedecryption_share: E::TargetFieldvalidator_checksum: ValidatorShareChecksum<E>

Implementations

Source

impl<E: Pairing> DecryptionSharePrecomputed<E>

pub fn create( validator_index: usize, validator_decryption_key: &E::ScalarField, private_key_share: &PrivateKeyShare<E>, ciphertext_header: &CiphertextHeader<E>, aad: &[u8], lagrange_coeff: &E::ScalarField, ) -> Result<Self>

Create a decryption share from the given parameters. This function checks that the ciphertext is valid.

pub fn create_unchecked( validator_index: usize, validator_decryption_key: &E::ScalarField, private_key_share: &PrivateKeyShare<E>, ciphertext_header: &CiphertextHeader<E>, lagrange_coeff: &E::ScalarField, ) -> Result<Self>

Create a decryption share from the given parameters. This function does not check that the ciphertext is valid.

pub fn verify( &self, share_aggregate: &E::G2Affine, validator_public_key: &E::G2Affine, ciphertext: &Ciphertext<E>, ) -> bool

Verify that the decryption share is valid.