pub struct DecryptionShareSimple<E: Pairing> {
pub decryption_share: E::TargetField,
pub validator_checksum: ValidatorShareChecksum<E>,
}Expand description
A decryption share for a simple variant of the threshold decryption scheme. In this variant, the decryption share require additional computation on the client side int order to be combined.
Fields
validator_checksum: ValidatorShareChecksum<E>Implementations
Sourcepub fn create(
validator_decryption_key: &E::ScalarField,
private_key_share: &PrivateKeyShare<E>,
ciphertext_header: &CiphertextHeader<E>,
aad: &[u8],
) -> Result<Self>
pub fn create( validator_decryption_key: &E::ScalarField, private_key_share: &PrivateKeyShare<E>, ciphertext_header: &CiphertextHeader<E>, aad: &[u8], ) -> Result<Self>
Create a decryption share from the given parameters. This function checks that the ciphertext is valid.
Sourcepub fn create_unchecked(
validator_decryption_key: &E::ScalarField,
private_key_share: &PrivateKeyShare<E>,
ciphertext_header: &CiphertextHeader<E>,
) -> Result<Self>
pub fn create_unchecked( validator_decryption_key: &E::ScalarField, private_key_share: &PrivateKeyShare<E>, ciphertext_header: &CiphertextHeader<E>, ) -> Result<Self>
Create a decryption share from the given parameters. This function does not check that the ciphertext is valid.